@@ -3,7 +3,8 @@
 from abc import ABC
 import logging
 import inspect
-from typing import Callable, Type, Dict, Union, Tuple, List
+import functools
+from typing import Callable, Dict, Union, Tuple, List, Type
 
 import tensorflow as tf
 
@@ -32,16 +33,19 @@ class Layer(ABC):
     The basic usage of a :class:`~Layer` is to build graphs as intuitively as
     possible. For example:
 
+    >>> from deepr.layers import Dense
     >>> input_tensor = tf.ones([32, 8])
     >>> dense = Dense(16)
     >>> output_tensor = dense(input_tensor)
-    tf.Tensor(shape=[32, 16])
+    >>> output_tensor
+    <tf.Tensor 'dense/BiasAdd:0' shape=(32, 16) dtype=float32>
 
 
     Because some layers (like :class:`~Dropout`) might behave differently
     depending on the mode (TRAIN, EVAL, PREDICT), an optional argument
     can be provided:
 
+    >>> from deepr.layers import Dropout
     >>> tensor = tf.ones([32, 8])
     >>> dropout = Dropout(0.5)
     >>> dropped = dropout(input_tensor, tf.estimator.ModeKeys.TRAIN)
@@ -51,10 +55,12 @@ class Layer(ABC):
     dictionary, yielded by a tf.data.Dataset for example, you can also
     do:
 
+    >>> tf.reset_default_graph()
     >>> tensors = {"x": tf.ones([32, 8])}
     >>> dense = Dense(16, inputs="x", outputs="y")
     >>> tensors = dense(tensors)
-    {"y": tf.Tensor(shape=[32, 16])}
+    >>> tensors
+    {'y': <tf.Tensor 'dense/BiasAdd:0' shape=(32, 16) dtype=float32>}
 
     The `inputs` and `outputs` are optional (defaults to t_0, t_1 etc.)
     and their order needs to be coherent with the order of tensors in
@@ -80,9 +86,13 @@ class Layer(ABC):
     should not create variables at instantiation time nor store
     variables or any other graph references as attributes.
 
+    >>> tf.reset_default_graph()
     >>> dense = Dense(16)
+
     No parameters are created
     >>> dense(tf.ones([32, 8]))
+    <tf.Tensor 'dense/BiasAdd:0' shape=(32, 16) dtype=float32>
+
     Parameters are created in the current tf.Graph
 
     In other words, calling the layer should not change its state. This
@@ -95,9 +105,15 @@ class Layer(ABC):
     arguments at call time. Behind the scene, it's simply wrapping the
     TF1.X variable management into a :meth:`~tf.variable_scope`.
 
+    >>> tf.reset_default_graph()
     >>> dense = Dense(16)
-    >>> dense(tf.ones([32, 8])) == dense(tf.ones([32, 8]), reuse=True)
-    True
+    >>> dense(tf.ones([32, 8]))
+    <tf.Tensor 'dense/BiasAdd:0' shape=(32, 16) dtype=float32>
+    >>> dense(tf.ones([32, 8]), reuse=True)
+    <tf.Tensor 'dense_1/BiasAdd:0' shape=(32, 16) dtype=float32>
+
+    While the two operations have different names 'dense/BiasAdd:0' and
+    'dense_1/BiasAdd:0', they both share the same weights.
 
     Good examples on how to implement parametrized layers are deepr.Dense
     and embedding.Embedding.
@@ -132,6 +148,12 @@ class Layer(ABC):
         if n_out is None and outputs is None:
             raise ValueError("You must set either n_out or outputs (both are None)")
 
+        def _default_names(num: int, prefix: str = "t_"):
+            if num == 1:
+                return f"{prefix}0"
+            else:
+                return tuple(f"{prefix}{idx}" for idx in range(num))
+
         # Resolve n_in / inputs from arguments
         if n_in is None and inputs is not None:
             n_in = len(to_flat_tuple(inputs))
@@ -219,7 +241,7 @@ class Layer(ABC):
             if isinstance(tensors, dict):
                 # Check that tensors is coherent with self.inputs
                 if not set(to_flat_tuple(self.inputs)) <= set(tensors):
-                    msg = f"Missing inputs: {set(to_flat_tuple(self.inputs)) - set(tensors)}"
+                    msg = f"{self} missing inputs: {set(to_flat_tuple(self.inputs)) - set(tensors)}"
                     raise KeyError(msg)
 
                 # Call forward_as_dict to get output tensors
@@ -227,17 +249,17 @@ class Layer(ABC):
 
                 # Check that tensors_dict is coherent with self.outputs
                 if not set(to_flat_tuple(self.outputs)) <= set(tensors_dict):
-                    msg = f"Missing outputs: {set(to_flat_tuple(self.outputs)) - set(tensors_dict)}"
+                    msg = f"{self} missing outputs: {set(to_flat_tuple(self.outputs)) - set(tensors_dict)}"
                     raise KeyError(msg)
 
                 return tensors_dict
             else:
                 # Check that tensors is coherent with self.n_in
                 if self.n_in == 1 and isinstance(tensors, tuple):
-                    msg = f"Expected 1 input, but got {tensors} (should not be a tuple)"
+                    msg = f"{self} expected 1 input, but got {tensors} (should not be a tuple)"
                     raise KeyError(msg)
                 if self.n_in > 1 and len(to_flat_tuple(tensors)) != self.n_in:
-                    msg = f"Expected {self.n_in} inputs, but got {tensors}"
+                    msg = f"{self} expected {self.n_in} inputs, but got {tensors}"
                     raise KeyError(msg)
 
                 # Call forward and convert to tuple
@@ -303,21 +325,22 @@ class Layer(ABC):
 
 
 def layer(
+    fn: Callable = None,
     n_in: int = None,
     n_out: int = None,
     inputs: Union[str, Tuple[str, ...], List[str]] = None,
     outputs: Union[str, Tuple[str, ...], List[str]] = None,
 ):
-    """Decorator that creates a layer from a function
+    """Decorator that creates a layer constructor from a function.
 
-    This decorator can be used to define :class:`~Layer` classes in a non
-    verbose way.
+    The decorator returns a subclass of :class:`~Layer`
+    whose ``forward`` method is defined by the decorated function.
 
-    For example, the following snippet defines a subclass of :class:`~Layer`
-    whose `forward` method returns `tensors + offset`.
+    For example
 
+    >>> from deepr.layers import layer
     >>> @layer(n_in=1, n_out=1)
-    ... def AddOffset(tensors, offset):
+    ... def AddOffset(tensors, mode, offset):
     ...     return tensors + offset
     >>> add = AddOffset(offset=1)
     >>> add(1)
@@ -337,14 +360,13 @@ def layer(
                 return tensors + self.offset
 
     You can also add a 'mode' argument to your layer like so
-
     >>> @layer(n_in=1, n_out=1)
-    ... def AddOffset(tensors, mode, offset):
+    ... def AddOffsetInTrain(tensors, mode, offset):
     ...     if mode == tf.estimator.ModeKeys.TRAIN:
     ...         return tensors + offset
     ...     else:
     ...         return tensors
-    >>> add = AddOffset(offset=1)
+    >>> add = AddOffsetInTrain(offset=1)
     >>> add(1, tf.estimator.ModeKeys.TRAIN)
     2
     >>> add(1, tf.estimator.ModeKeys.PREDICT)
@@ -352,87 +374,47 @@ def layer(
 
     Note that 'tensors' and 'mode' need to be the the first arguments
     of the function IN THIS ORDER.
-
-    Another way of using the decorator is on functions that create layer
-    instances. This allows you to create factories of layers and make
-    them :class:`~Layer` classes.
-
-    For example, the following snippet defines a subclass of :class:`~Layer`
-    whose `forward` method is the same as the layer returned by the
-    function.
-
-    >>> @layer(n_in=1, n_out=1)
-    ... def AddOne() -> Layer:
-    ...     return AddOffset(offset=1)
-    >>> add_one = AddOne()
-    >>> add_one(1)
-    2
-
-    A nice feature of the :class:`~layer` decorator is laziness: the code
-    inside the function is not executed until a call on a tensor. In
-    other words:
-
-    >>> @layer(n_in=1, n_out=1)
-    ... def AddOffset(tensors, offset):
-    ...     print("Calling layer")
-    ...     return tensors + offset
-    >>> add_one = AddOffset(offset=1)
-    >>> add_one(1)
-    "Calling layer"
     """
     # pylint: disable=protected-access,invalid-name
-
     def _create_layer_class(fn: Callable) -> Type[Layer]:
-        """Decorator that creates a Layer class from a function"""
+        """Decorator that creates a Layer constructor."""
         parameters = inspect.signature(fn).parameters
         signature = inspect.Signature([param for key, param in parameters.items() if key not in {"tensors", "mode"}])
 
-        if "tensors" in parameters:  # From a `forward` function
-
-            if list(parameters.keys())[0] != "tensors":
-                raise TypeError(f"'tensors' should be the first positional argument")
-
-            if "mode" in parameters:
-
-                if list(parameters.keys())[1] != "mode":
-                    raise TypeError(f"'mode' should be the second positional argument")
-
-                def _forward(self, tensors, mode: str = None):
-                    return fn(tensors, mode, *self._args, **self._kwargs)
-
-            else:
-
-                def _forward(self, tensors, mode: str = None):
-                    # pylint: disable=unused-argument
-                    return fn(tensors, *self._args, **self._kwargs)
-
-        else:  # From a constructor
-
-            def _forward(self, tensors, mode: str = None):
-                return fn(*self._args, **self._kwargs).forward(tensors, mode)
+        # Check parameters
+        if list(parameters.keys())[0] != "tensors":
+            raise TypeError(f"'tensors' should be the first parameter of {fn.__name__}")
+        if "mode" in parameters:
+            if list(parameters.keys())[1] != "mode":
+                raise TypeError(f"'mode' should be the second parameter of {fn.__name__}")
 
+        @functools.wraps(fn)
         def _init(self, *args, **kwargs):
-            # Extract base.Layer arguments from kwargs
             _n_in = kwargs.pop("n_in") if "n_in" in kwargs else n_in
             _n_out = kwargs.pop("n_out") if "n_out" in kwargs else n_out
             _inputs = kwargs.pop("inputs") if "inputs" in kwargs else inputs
             _outputs = kwargs.pop("outputs") if "outputs" in kwargs else outputs
             _name = kwargs.pop("name") if "name" in kwargs else None
             Layer.__init__(self, n_in=_n_in, n_out=_n_out, inputs=_inputs, outputs=_outputs, name=_name)
-
-            # Check and store arguments for the wrapped function
             signature.bind(*args, **kwargs)
             self._args = args
             self._kwargs = kwargs
 
+        if "mode" in parameters:
+
+            def _forward(self, tensors, mode: str = None):
+                return fn(tensors, mode, *self._args, **self._kwargs)
+
+        else:
+
+            def _forward(self, tensors, mode: str = None):
+                # pylint: disable=unused-argument
+                return fn(tensors, *self._args, **self._kwargs)
+
         attributes = {"__module__": fn.__module__, "__doc__": fn.__doc__, "__init__": _init, "forward": _forward}
         return type(fn.__name__, (Layer,), attributes)
 
-    return _create_layer_class
-
-
-def _default_names(num: int, prefix: str = "t_"):
-    if num == 1:
-        return f"{prefix}0"
+    if fn is not None:
+        return _create_layer_class(fn)
     else:
-        return tuple(f"{prefix}{idx}" for idx in range(num))
+        return _create_layer_class
