@@ -51,6 +51,9 @@ class Field:
     def __str__(self):
         return self.name
 
+    def __hash__(self):
+        return hash(self.name)
+
     @property
     def feature_specs(self):
         """Return feature specs for parsing Example messages."""
@@ -67,6 +70,10 @@ class Field:
             else:
                 return tf.io.FixedLenFeature(shape=self.shape, dtype=self.dtype)
 
+    @property
+    def batch_shape(self):
+        return tuple([None] + list(self.shape))
+
     def is_sparse(self) -> bool:
         if self.is_featurizable():
             return isinstance(self.feature_specs, tf.io.VarLenFeature)
